# ============ List of structure to annotate ============

LIST_STRUCTURES = [
    "BONES",
    "MUSCLES",
]

DICT_SUB_STRUCTURES = {
    "BONES":[
        'Clavicle',
        'Acromion',
        'Humerus',
        'Humeral Head',
        'Scapula',
        'Glenoid',
        'Coracoid process',
        'Elbow'],
    "MUSCLES": [
        'Supraspinatus ',
        'Infra spinatus',
        'Teres minor',
        'Deltoid anterior',
        'Deltoid lateral part',
        'Deltoid posterior part',
        'Sub scapularis ',
        'Triceps brachii',
        'Coraco-Brachialis',
        'Pec major',
        'Pec minor',
        'Latissimus dorsi',
        'Rhomboid',
        'Trapezius',
        'Long Biceps']
}

DICT_SUB_SUB_STRUCTURES = {
    "Scapula":[
        'Body',
        'Epine',
        'Acromion',
        'Coracoid'],
    "Humeral Head" : [
        'Trochiter',
        'Trochin',
        'Tete',
        'Diaphise'],
    "Muscle de la coiffe": [
        'Supra',
        'Infra',
        'Supscapu'],
    "Elbow": [
        'ole crade',
        'Radius',
        'Palet humérale'],
}

# COLUMN_WIDTH = 30